#
# spec file for package libvdpau-va-gl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  libvdpau_va_gl
%define sover   1
Name:           libvdpau-va-gl
Version:        0.4.2
Release:        lp150.1.3
Summary:        VDPAU driver with OpenGL/VAAPI backend
License:        LGPL-3.0+
Group:          System/Libraries
Url:            https://github.com/i-rinat/libvdpau-va-gl
Source:         https://github.com/i-rinat/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(vdpau)
%if 0%{?suse_version} > 1320
BuildRequires:  gcc-c++
%else
# C++11 unified initialisation is of need.
BuildRequires:  gcc5-c++
%endif

%description
Many applications can use VDPAU to accelerate portions of the video
decoding process and video post-processing to the GPU video hardware.
Unfortunately, there is no such library for many graphic chipsets.
Some applications also support VA-API but many of them, including
Adobe Flash Player, don't.

This library proposes a generic VDPAU library. It uses OpenGL under
the hood to accelerate drawing and scaling and VA-API (if
available) to accelerate video decoding.

%package -n %{soname}%{sover}
Summary:        VDPAU driver with OpenGL/VAAPI backend
Group:          System/Libraries
Supplements:    xf86-video-intel
Provides:       %{soname} = %{version}

%description -n %{soname}%{sover}
Many applications can use VDPAU to accelerate portions of the video
decoding process and video post-processing to the GPU video hardware.
Unfortunately, there is no such library for many graphic chipsets.
Some applications also support VA-API but many of them, including
Adobe Flash Player, don't.

This library proposes a generic VDPAU library. It uses OpenGL under
the hood to accelerate drawing and scaling and VA-API (if
available) to accelerate video decoding.

%prep
%setup -q
cat > %{name}.sh << EOF
# Avoid usage of this library when NVIDIA's proprietary driver is running.
if [ ! -c /dev/nvidiactl ]; then
    export VDPAU_DRIVER='va_gl'
fi
EOF
cat > %{name}.csh << EOF
# Avoid usage of this library when NVIDIA's proprietary driver is running.
if ( ! -c /dev/nvidiactl ) then
    setenv VDPAU_DRIVER 'va_gl'
endif
EOF

%build
%if 0%{?suse_version} <= 1320
export CC="gcc-5"
export CXX="g++-5"
# Default ABI up to G++4.9.
export CXXFLAGS="%{optflags} -fabi-version=2 -fabi-compat-version=2"
%endif
%cmake \
  -DLIB_INSTALL_DIR=%{_libdir}/vdpau
make %{?_smp_mflags} V=1

%install
%cmake_install

install -Dpm 0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -Dpm 0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh

%files -n %{soname}%{sover}
%defattr(-,root,root)
%doc ChangeLog LICENSE README.md
%config %{_sysconfdir}/profile.d/%{name}.*sh
%{_libdir}/vdpau/

%changelog
* Tue Nov 15 2016 sor.alexei@meowr.ru
- Update to version 0.4.2 (changes since 0.4.0):
  * Fix a resource leak in VideoSurface.
  * Fix compiling against libc++.
  * Hardcode 4096x4096 as a maximum video surface resolution.
- Use G++ 5 in openSUSE Leap 42.x to compile the unified
  initialisers in ByteReader in src/bitstream.hh, thanks to
  Max Staudt <mstaudt@suse.com> (boo#1008763).
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.4.0:
  * Code now requires C++11-capable compiler.
  * GLib, GLU, and libswscale dependencies are dropped.
  * Drop own tracing code; libvdpau have own tracing already.
  * Change VdpVideoMixerRender's destination_video_rect handling
    with VLC to fix video scaling.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 0.3.6:
  * core: Handle Constrained Baseline profile for H.264.
  * misc: Bugfixes.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to 0.3.5:
  * misc: Compatibility with some other ffmpeg versions.
  * misc: Bugfixes.
* Mon Feb 16 2015 sndirsch@suse.com
- /etc/profile.d/libvdpau-va-gl.{csh,sh}: do not set VDPAU_DRIVER,
  if NVIDIA's proprietary driver is installed
* Thu Sep 25 2014 sor.alexei@meowr.ru
- Supplement xf86-video-intel as the only possible libvdpau there.
- Usage of %%cmake and %%cmake_install macros.
- Add baselibs.conf.
- Remove incorrect usage of %%ghost.
* Sat Apr  5 2014 tittiatcoke@gmail.com
- Correct the usage of cmake and use make install to install
  the libraries.
* Sat Apr  5 2014 sor.alexei@meowr.ru
- Remove _service and upload tarball locally.
* Fri Apr  4 2014 sor.alexei@meowr.ru
- Fixes for /etc/profile.d/.
* Wed Apr  2 2014 p.drouand@gmail.com
- Does not Provides/Obsoletes libvdpau-va-gl as the package never
  exist.
- Remove useless %%files section.
- The profile script do not need to get executable bits.
* Wed Apr  2 2014 sor.alexei@meowr.ru
- Initial package.
